@@ -10,9 +10,6 @@ import (
 	"github.com/rs/zerolog/pkgerrors"
 	"github.com/stretchr/testify/assert"
 	"github.com/twpayne/go-vfs/v4"
-	"golang.org/x/exp/constraints"
-	"golang.org/x/exp/maps"
-	"golang.org/x/exp/slices"
 
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoitest"
 )
@@ -40,11 +37,11 @@ func TestEtcHostsFQDNHostname(t *testing.T) {
 					`127.0.0.1       localhost`,
 					``,
 					`# 127.0.1.1 is often used for the FQDN of the machine`,
-					`127.0.1.1       thishost.mydomain.org  thishost`,
-					`192.168.1.10    foo.mydomain.org       foo`,
-					`192.168.1.13    bar.mydomain.org       bar`,
-					`146.82.138.7    master.debian.org      master`,
-					`209.237.226.90  www.opensource.org`,
+					`127.0.1.1       host.example.com   host`,
+					`192.168.1.10    foo.example.com    foo`,
+					`192.168.1.13    bar.example.com    bar`,
+					`146.82.138.7    master.debian.org  master`,
+					`209.237.226.90  www.example.org`,
 					``,
 					`# The following lines are desirable for IPv6 capable hosts`,
 					`::1             localhost ip6-localhost ip6-loopback`,
@@ -53,28 +50,28 @@ func TestEtcHostsFQDNHostname(t *testing.T) {
 				),
 			},
 			f:        etcHostsFQDNHostname,
-			expected: "thishost.mydomain.org",
+			expected: "host.example.com",
 		},
 		{
 			name: "etc_hosts_whitespace_and_comments",
 			root: map[string]any{
 				"/etc/hosts": chezmoitest.JoinLines(
-					" \t127.0.1.1 \tthishost.mydomain.org# comment",
+					" \t127.0.1.1 \thost.example.com# comment",
 				),
 			},
 			f:        etcHostsFQDNHostname,
-			expected: "thishost.mydomain.org",
+			expected: "host.example.com",
 		},
 		{
 			name: "etc_hosts_missing_canonical_hostname",
 			root: map[string]any{
 				"/etc/hosts": chezmoitest.JoinLines(
 					`127.0.1.1`,
-					`127.0.1.1 thishost.mydomain.org`,
+					`127.0.1.1 host.example.com`,
 				),
 			},
 			f:        etcHostsFQDNHostname,
-			expected: "thishost.mydomain.org",
+			expected: "host.example.com",
 		},
 		{
 			name: "etc_hostname",
@@ -176,9 +173,3 @@ func TestUniqueAbbreviations(t *testing.T) {
 		})
 	}
 }
-
-func sortedKeys[K constraints.Ordered, V any](m map[K]V) []K {
-	keys := maps.Keys(m)
-	slices.Sort(keys)
-	return keys
-}
